# Updated docs to come soon for version 4 !!!

# Vue Single Sign On

[![Codeship Status for peteringram0/Vue-SSO](https://app.codeship.com/projects/f42b3e30-431e-0135-e330-1eb4ca255e7d/status?branch=master)](https://app.codeship.com/projects/230562)

[![npm version](https://badge.fury.io/js/vue-sso.svg)](https://badge.fury.io/js/vue-sso)

A Small (3kb) login manager package for when using JSON web tokens using Axios within Vue.JS

This is a small vue plugin which will handle everything todo with login. 
Its designed to be used with Axios will set all the settings needed to make axios
to a API which requires JTW's within the Axios request. It also handles refreshing the token
before its expired if you specify within the options.

# Install
````bash
$ yarn install vue-sso
````

````javascript

import SSO from 'vue-sso';

Vue.use(SSO, {
    
    /**
    * Projects base URL
    */
    baseURL: '/api',
    
    /**
    * Projects auth endpoint (*include slash) (*Default is '/auth/login', override is optional)
    */
    authEndpoint: '/auth/login',
    
    /**
    * NOT REQUIRED
    * 
    * If specified this is the endpoint location that will update your tokens expirary time
    * with your existing token. (Same response as the authEndpoint with updated token or expire)
    */
    refresh: '/auth/refresh_token',
    
    /**
    * Name used for the localStorege token (Application Name)
    */
    key: 'my-app'
    
});

````

### Note
* This plugin expects access to Axios on the window object. Axios is a dependency of this package but not included
within build to avoid dependency duplication.

````javascript
import Axios from 'axios';
window.axios = Axios
````

# Usage
All available methods listed below. These are all accessible from your root instance of Vue.

## Login
````javascript
this.$SSO.login(USER, PASS)
    .then(r => {
        // Promise will resolve on success
        // Token will be stored in localStorage for you
        // Axios defaults will be set for you
        // If set the token will automatically re-new for you
    });
````

## Logout
````javascript
this.$SSO.logout()
    .then(r => {
        // Promise will resolve on success
        // Token will be cleared from localStorage for you
        // Axios defaults will be removed
    });
````

## Logged In Check
````javascript
let loggedIn = this.$SSO.loggedin();

console.log(loggedIn); // TRUE or FALSE
````

### Notes
This plugin expects that the response for the auth and refresh endpoints specifed within the options 
to look like the following: (*Note any additional information received will be stored within LocalStorage)

```javascript
{
    token: 'TOKEN HERE',
    expire: "2017-06-30T13:40:00Z"
}
```

### License

MIT License

Copyright (c) 2017 Peter Ingram

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
